@@ -14,7 +14,7 @@ sub count : method {
 sub empty : method {
     my ($attr, $reader, $writer) = @_;
     return sub { 
-        scalar @{$reader->($_[0])} ? 1 : 0 
+        scalar @{$reader->($_[0])} ? 1 : 0
     };        
 }
 
@@ -45,6 +45,22 @@ sub grep : method {
     };
 }
 
+sub elements : method {
+    my ($attr, $reader, $writer) = @_;
+    return sub {
+        my ($instance) = @_;
+        @{$reader->($instance)}
+    };
+}
+
+sub join : method {
+    my ($attr, $reader, $writer) = @_;
+    return sub {
+        my ($instance, $separator) = @_;
+        join $separator, @{$reader->($instance)}
+    };
+}
+
 1;
 
 __END__
@@ -82,6 +98,10 @@ L<MooseX::AttributeHelpers::Collection::List>.
 
 =item B<map>
 
+=item B<elements>
+
+=item B<join>
+
 =back
 
 =head1 BUGS
